/*
 * Web Fonts from fontspring.com
 *
 * All OpenType features and all extended glyphs have been removed.
 * Fully installable fonts can be purchased at http://www.fontspring.com
 *
 * The fonts included in this stylesheet are subject to the End User License you purchased
 * from Fontspring. The fonts are protected under domestic and international trademark and 
 * copyright law. You are prohibited from modifying, reverse engineering, duplicating, or
 * distributing this font software.
 *
 * (c) 2010-2012 Fontspring
 *
 *
 *
 *
 * The fonts included are copyrighted by the vendor listed below.
 *
 * Vendor:      exljbris
 * License URL: http://www.fontspring.com/fflicense/exljbris
 *
 *
 */

@font-face {
    font-family: 'Museo500Regular';
    src: url('Museo500-Regular-webfont.eot');
    src: url('Museo500-Regular-webfont.eot?#iefix') format('embedded-opentype'),
         url('Museo500-Regular-webfont.woff') format('woff'),
         url('Museo500-Regular-webfont.ttf') format('truetype'),
         url('Museo500-Regular-webfont.svg#Museo500Regular') format('svg');
    font-weight: normal;
    font-style: normal;

}

